@@ -1,10 +1,10 @@
-# Copyrights 2008-2016 by [Mark Overmeer].
+# Copyrights 2008-2017 by [Mark Overmeer].
 #  For other contributors see ChangeLog.
 # See the manual pages for details on the licensing terms.
 # Pod stripped from pm file by OODoc 2.02.
 package XML::LibXML::Simple;
 use vars '$VERSION';
-$VERSION = '0.96';
+$VERSION = '0.98';
 
 use base 'Exporter';
 
@@ -15,7 +15,6 @@ our @EXPORT    = qw(XMLin);
 our @EXPORT_OK = qw(xml_in);
 
 use XML::LibXML       ();
-use File::Slurp::Tiny qw/read_file/;
 use File::Basename    qw/fileparse/;
 use File::Spec        ();
 use Carp;
@@ -27,7 +26,7 @@ use Data::Dumper;  #to be removed
 my %known_opts = map +($_ => 1),
   qw(keyattr keeproot forcecontent contentkey noattr searchpath
      forcearray grouptags nsexpand normalisespace normalizespace
-     valueattr nsstrip parser parseropts);
+     valueattr nsstrip parser parseropts hooknodes);
 
 my @default_attributes  = qw(name key id);
 my $default_content_key = 'content';
